/***********************************************************************/
/*                                                                     */
/*  PROJECT		  :FTF Design Challenge Europe 2008   	                 */
/*  AUTHOR      :Carlos Cossio                                         */
/*  FILE        :ADC.c                                                 */
/*  DATE        :June 21, 2008                                         */
/*  DESCRIPTION :This file allows to manage the ADC converter          */
/*                                                                     */
/***********************************************************************/


#include "ADC.h"


/******************************************************************************
Name       : ADC_Init
Author     : Carlos Cossio
Parameters : None
Returns    : None
Description: Setup the ADC driver
******************************************************************************/
void ADC_Init (void)
{
  ADCSC1 = 0x1F;                          // Disable interrupts 
                                          // Disable continuous conversions
                                          // Disable ADC by setting all ADCH bits
  ADCSC2 = 0x00;                          // Select S/W trigger
                                          // Disable compare function
  ADCCFG = 0x07; 	                        // ADIV = input clock/1
                                          // ADLSMP = long sample time
                                          // MODE = 12-bit conversion
                                          // ADICLK = async clock
  APCTL1 = 0x03;                          // Enable ADP0 and ADP1 as ADC input
}


/******************************************************************************
Name       : ADC_Start
Author     : Carlos Cossio
Parameters : channel -> CURRENT_SENSOR or POT
Returns    : None
Description: Start the ADC
******************************************************************************/
void ADC_Start (unsigned char channel)
{
  ADCSC1_ADCH = channel;                  // Channel number
}


/******************************************************************************
Name       : ADC_Read
Author     : Carlos Cossio
Parameters : channel -> CURRENT_SENSOR or POT
Returns    : 12-bit	result
Description: Get a 12-bit value from the ADC channel
******************************************************************************/
unsigned int ADC_Read (unsigned char channel)
{	
  char i;
  unsigned int temp;
  unsigned int sample = 0;
    
     
  for (i = 0; i < 8; i++) {               // Do the ADC conversion 8 times for better accuracy
    ADC_Start (channel);                  // Do single conversion
        
    while (!(ADCSC1_COCO));               // Wait for conversion done
        
    temp  = (unsigned int) (ADCRH<<8);    // Read ADC high value,
    temp |= (unsigned int) (ADCRL);       // Read ADC low byte, clear COCO flag
        
    sample += temp;                       // Accumulate result (8 samples) for later averaging
  }

  sample = sample >> 3;                   // Average the 8 samples

  return (sample & 0x0FFF);               // Return 12-bit result
}


/******************************************************************************
Name       : ADC_Stop
Author     : Carlos Cossio
Parameters : None
Returns    : None
Description: Stop the ADC
******************************************************************************/
void ADC_Stop (void)
{

}
