/***********************************************************************/
/*                                                                     */
/*  PROJECT		  :FTF Design Challenge Europe 2008   	                 */
/*  AUTHOR      :Carlos Cossio                                         */
/*  FILE        :ByeByeStandby.c                                       */
/*  DATE        :June 21, 2008                                         */
/*  DESCRIPTION :This file allows to define the application            */
/*                                                                     */
/***********************************************************************/


#include "ByeByeStandby.h"                // Include variable declarations
#include "ADC.h"                          // A/D library functions
#include "IR.h"                           // IR library functions
#include "LED.h"                          // Relay library functions
#include "Relay.h"                        // RTC library functions
#include "RTC.h"                          // MCU library functions
#include "MCU.h"


/*****************************************************************************
Name:   	   ByeByeStandby_Init        
Author     : Carlos Cossio
Parameters:  None
Returns:     None
Description: This function allows to initialize the ByeByeStandby hardware
*****************************************************************************/
void ByeByeStandby_Init (void)
{ 
  ADC_Init();                             // Initialize ADC converter
  Relay_Init();                           // Initialize the relay
  IR_Init();                              // Initialize the IR receiver
  LED_Init();                             // Initialize the LED
  RTC_Init();                             // Initialize the RTC counter
  MCU_Init();                             // Initialize MCU resources
}


/*****************************************************************************
Name:   	   ByeByeStandby_Welcome        
Author     : Carlos Cossio
Parameters:  None
Returns:     None
Description: This function allows to flash the LED five times
*****************************************************************************/
void ByeByeStandby_Welcome (void)
{ 
  LED_On();                               // LED on
  RTC_Delay (100);                        // Wait 100 ms
  LED_Off();                              // LED off
  RTC_Delay (100);                        // Wait 100 ms
  LED_On();                               // LED on
  RTC_Delay (100);                        // Wait 100 ms
  LED_Off();                              // LED off
  RTC_Delay (100);                        // Wait 100 ms
  LED_On();                               // LED on
  RTC_Delay (100);                        // Wait 100 ms
  LED_Off();                              // LED off
  RTC_Delay (100);                        // Wait 100 ms
  LED_On();                               // LED on
  RTC_Delay (100);                        // Wait 100 ms
  LED_Off();                              // LED off
  RTC_Delay (100);                        // Wait 100 ms
  LED_On();                               // LED on
  RTC_Delay (100);                        // Wait 100 ms
  LED_Off();                              // LED off
}


/*****************************************************************************
Name:   	   ByeByeStandby_On
Author     : Carlos Cossio        
Parameters:  None
Returns:     None
Description: This function allows to switch on the peripheral attached 
*****************************************************************************/
void ByeByeStandby_On (void)
{ 
  if (Relay_Mode() == RELAY_OPEN) {       // Only if the relay is open
    Relay_Closed();                       // Turn on peripheral attached
    LED_On();                             // LED on
  }
}


/*****************************************************************************
Name:   	   ByeByeStandby_Off        
Author     : Carlos Cossio
Parameters:  None
Returns:     None
Description: This function allows to switch off the peripheral attached 
*****************************************************************************/
void ByeByeStandby_Off (void)
{
  if (Relay_Mode() == RELAY_CLOSED) {     // Only if the relay is closed
    Relay_Open();                         // Turn off peripheral attached
    LED_Off();                            // LED off
  }
}


/*****************************************************************************
Name:   	   ByeByeStandby_Mode        
Author     : Carlos Cossio
Parameters:  None
Returns:     mode: BYE_BYE_STANDBY_ON: 1 or BYE_BYE_STANDBY_OFF: 0
Description: Return the ByeByeStandby running mode: on or off  
*****************************************************************************/
unsigned char ByeByeStandby_Mode (void)
{
  if (Relay_Mode() == RELAY_CLOSED)
    return BYE_BYE_STANDBY_ON;            // ByeByeStandby is on
  else                                          
    return BYE_BYE_STANDBY_OFF;           // ByeByeStandby is off
}


/*****************************************************************************
Name:   	   ByeByeStandby_InfraredRemoteControlKeyPressed   
Author     : Carlos Cossio     
Parameters:  None
Returns:     None
Description: This function allows to know if a key has been pressed on the
             IR remote control
*****************************************************************************/
unsigned char ByeByeStandby_InfraredRemoteControlKeyPressed (void)
{ 
  return IR_Mode();                       // Return IR status
}


/*****************************************************************************
Name:   	   ByeByeStandby_PeripheralInStandbyMode
Author     : Carlos Cossio
Parameters:  None
Returns:     None
Description: This function allows to check the status of the peripheral attached 
*****************************************************************************/
unsigned char ByeByeStandby_PeripheralInStandbyMode (void)
{ 
  if (ADC_Read(CURRENT_SENSOR) < BYE_BYE_STANDBY_CURRENT_THRESHOLD) {
    RTC_Delay(5000);                      // Wait for 5 seconds
    if (ADC_Read(CURRENT_SENSOR) < BYE_BYE_STANDBY_CURRENT_THRESHOLD)  
	    return YES;                         // Peripheral attached is in standby
	  else
	    return FALSE;                       // Peripheral attached is still on
  }
	else { 
	  return FALSE;                         // Peripheral attached is on
	}
}

/*****************************************************************************
Name:   	   ByeByeStandby_Sleep
Author     : Carlos Cossio
Parameters:  None
Returns:     None
Description: This function allows to enter low power mode
*****************************************************************************/
void ByeByeStandby_Sleep (void)
{ 
  switch (ByeByeStandby_Mode()) {
    case BYE_BYE_STANDBY_OFF:             // If ByeByeStandby is off ...
      IR_Enable();                        // Enable IR interrupts
      RTC_Disable();                      // Disable RTC interrupts
      LowPowerMode;                       // Enter low-power mode
      break;
      
    case BYE_BYE_STANDBY_ON:              // If ByeByeStandby is on ...
      IR_Disable();                       // Disable IR interrupts
      RTC_Enable();                       // Enable RTC interrupts every half a second
      LowPowerMode;                       // Enter low-power mode
      break;
      
    default:
      break;
  }
}
