/***********************************************************************/
/*                                                                     */
/*  PROJECT		  :FTF Design Challenge Europe 2008   	                 */
/*  AUTHOR      :Carlos Cossio                                         */
/*  FILE        :IR.c                                                  */
/*  DATE        :June 21, 2008                                         */
/*  DESCRIPTION :This file allows to manage the IR receiver            */
/*                                                                     */
/***********************************************************************/


#include "IR.h"
#include "RTC.h"


#pragma DATA_SEG _DATA_ZEROPAGE

static unsigned char IR_key_pressed;

#pragma DATA_SEG DEFAULT


/******************************************************************************
Name       : IR_Init
Author     : Carlos Cossio
Parameters : None
Returns    : None
Description: Setup the IR receiver driver
******************************************************************************/
void IR_Init (void)
{
  KBI1SC_KBIE = 0;                        // Mask KBI1 interrupts                                                                                       
  KBI1ES_KBEDG3 = 0;                      // KBI1P3 internal pull-up, falling edge/low level
  KBI1PE_KBIPE3 = 1;                      // Enable KBI1P3 interrupts                          
  KBI1SC_KBIMOD = 0;                      // Detect edges only                                             
  KBI1SC_KBACK = 1;                       // Clear possible false interrupts  
  KBI1SC_KBIE = 1;                        // Enable KBI1 interrupts
  IR_GPIO = IR_INPUT;                     // IR pin as input
  
  IR_key_pressed = NO;                    // No key pressed
}


/******************************************************************************
Name       : IR_Enable
Author     : Carlos Cossio
Parameters : None
Returns    : None
Description: Enable IR receiver interrupts
******************************************************************************/
void IR_Enable (void)
{
  KBI1SC_KBACK = 1;                       // Clear KBACK
  KBI1SC_KBIE  = 1;                       // Enable KBI1 interrupts    
}


/******************************************************************************
Name       : IR_Disable
Author     : Carlos Cossio
Parameters : None
Returns    : None
Description: Disable IR receiver interrupts
******************************************************************************/
void IR_Disable (void)
{
  KBI1SC_KBACK = 1;                       // Clear KBACK
  KBI1SC_KBIE  = 0;                       // Disable KBI1 interrupts    
}


/******************************************************************************
Name       : IR_Mode
Author     : Carlos Cossio
Parameters : None
Returns    : TRUE if a key is pressed on the IR remote control, otherwise FALSE
Description: Return if a key on the IR remote control has been pressed 
******************************************************************************/
unsigned char IR_Mode (void)
{
  if (IR_key_pressed == YES) {            // If key pressed flag is pending ...
    IR_key_pressed = NO;                  // Clear key pressed flag
    return TRUE;                          // Key pressed on the IR remote control
  }
  else
    return FALSE;                         // No key pressed on the IR remote control
}                                         


/******************************************************************************
Name       : IR_ISR
Author     : Carlos Cossio
Parameters : None
Returns    : None
Description: IR interrupt service routine
******************************************************************************/
interrupt VectorNumber_Vkeyboard void IR_ISR (void)
{   
  KBI1SC_KBIE  = 0;                       // Disable KBI1 interrupts  
  KBI1SC_KBACK = 1;                       // Clear KBACK

  if (Relay_Mode() == RELAY_OPEN) {       // IR command valid only when the relay is open
    
    RTC_Delay (1);                        // Wait for 1 ms to block sporadic short pulses from TSOP1236
    
    if (IR == IR_LOW)                     // If a valid low-pulse is detected ...
      IR_key_pressed = YES;               // Set key pressed flag 
  } 
}
