/***********************************************************************/
/*                                                                     */
/*  PROJECT		  :FTF Design Challenge Europe 2008   	                 */
/*  AUTHOR      :Carlos Cossio                                         */
/*  FILE        :MCU.c                                                 */
/*  DATE        :June 21, 2008                                         */
/*  DESCRIPTION :This file allows to initialize the microcontroller    */
/*               resources                                             */
/*                                                                     */
/***********************************************************************/


#include <hidef.h>                        // For EnableInterrupts macro
#include "derivative.h"                   // Include peripheral declarations
#include "MCU.h"


/******************************************************************************
Name       : MCU_Init
Author     : Carlos Cossio
Parameters : None
Returns    : None
Description: Setup the MCU resources
******************************************************************************/
void MCU_Init (void)
{
  SOPT1  = 0x23;                          // Disable COP,RSTO, enable STOP,BKGD,RESET
  SOPT2  = 0x00;                          // SPI1 on PTB2/3/4/5, IIC1 on PTA2/3
  SPMSC1 = 0x00;                          // Disable LVD
  SPMSC2 = 0x00;                          // Disable power-down modes
  SPMSC3 = 0x00;                          // Disable LVWIE, low trip points

  SCGC1_SCI1 = DISABLE;                   // Disable bus clock to SCI1
  SCGC1_SCI2 = DISABLE;                   // Disable bus clock to SCI2
  SCGC1_IIC1 = DISABLE;                   // Disable bus clock to IIC1
  SCGC1_IIC2 = DISABLE;                   // Disable bus clock to IIC2
  SCGC1_ADC  = ENABLE;                    // Enable bus clock to ADC
  SCGC1_TPM1 = DISABLE;                   // Disable bus clock to Timer1
  SCGC1_TPM2 = DISABLE;                   // Disable bus clock to Timer2
  SCGC1_TPM3 = DISABLE;                   // Disable bus clock to Timer3
  
  SCGC2_SPI1 = DISABLE;                   // Disable bus clock to SPI1
  SCGC2_SPI2 = DISABLE;                   // Disable bus clock to SPI2
  SCGC2_RTC  = ENABLE;                    // Enable bus clock to RTC
  SCGC2_ACMP = DISABLE;                   // Disable bus clock to Comparator
  SCGC2_KBI  = ENABLE;                    // Enable bus clock to Keyboard
  SCGC2_IRQ  = DISABLE;                   // Disable bus clock to IRQ
  SCGC2_FLS  = DISABLE;                   // Disable bus clock to FLS
  SCGC2_DBG  = ENABLE;                    // Enable bus clock to Debug
                                         
  PTAPE = 0xFF;                           // Enable PORT A Internal Pullups
  PTBPE = 0xFF;                           // Enable PORT B Internal Pullups
  PTCPE = 0xFF;                           // Enable PORT C Internal Pullups
  PTDPE = 0xFF;                           // Enable PORT D Internal Pullups
  PTEPE = 0xFF;                           // Enable PORT E Internal Pullups
  PTFPE = 0xFF;                           // Enable PORT F Internal Pullups
  PTGPE = 0x0F;                           // Enable PTG0/1/2/3 Internal Pullups
  PTHPE = 0xC3;                           // Enable PTH0/1/6/7 Internal Pullups

  EnableInterrupts;                       // Enable interrupts
}
