/***********************************************************************/
/*                                                                     */
/*  PROJECT		  :FTF Design Challenge Europe 2008   	                 */
/*  AUTHOR      :Carlos Cossio                                         */
/*  FILE        :Relay.c                                               */
/*  DATE        :June 21, 2008                                         */
/*  DESCRIPTION :This file allows to manage the latching relay driver  */
/*                                                                     */
/***********************************************************************/


#include "Relay.h"
#include "RTC.h"


#pragma DATA_SEG _DATA_ZEROPAGE

static unsigned char relay_mode;

#pragma DATA_SEG DEFAULT


/******************************************************************************
Name       : Relay_Init
Author     : Carlos Cossio
Parameters : None
Returns    : None
Description: Setup the latching relay driver
******************************************************************************/
void Relay_Init (void)
{
  RELAY_SET_STRENGTH = RELAY_STRONG;      // High output drive on RELAY_SET
  RELAY_RESET_STRENGTH = RELAY_STRONG;    // High output drive on RELAY_RESET
  RELAY_SET = RELAY_LOW;                  // RELAY_SET pin low
  RELAY_RESET = RELAY_LOW;                // RELAY_RESET pin low
  
  RELAY_SET_GPIO = RELAY_OUTPUT;          // RELAY_SET pin as output
  RELAY_RESET_GPIO = RELAY_OUTPUT;        // RELAY_RESET pin as output
  
  Relay_Open();                           // By default relay is open   
}


/******************************************************************************
Name       : Relay_Open
Author     : Carlos Cossio
Parameters : None
Returns    : None
Description: Open the latching relay
******************************************************************************/
void Relay_Open (void)
{
  RELAY_SET = RELAY_LOW;                  // RELAY_SET pin low
  RELAY_RESET = RELAY_HIGH;               // RELAY_RESET pin high
  
  RTC_Delay (50);					                // Pulse duration for 50 ms

  RELAY_SET = RELAY_LOW;                  // RELAY_SET pin low
  RELAY_RESET = RELAY_LOW;                // RELAY_RESET pin low
  
  relay_mode = RELAY_OPEN;                // Now the relay is open
}


/******************************************************************************
Name       : Relay_Closed
Author     : Carlos Cossio
Parameters : None
Returns    : None
Description: Close the latching relay
******************************************************************************/
void Relay_Closed (void)
{	
  RELAY_SET = RELAY_HIGH;                 // RELAY_SET pin high
  RELAY_RESET = RELAY_LOW;                // RELAY_RESET pin low
  
  RTC_Delay (50);	  				              // Pulse duration for 50 ms				

  RELAY_SET = RELAY_LOW;                  // RELAY_SET pin low
  RELAY_RESET = RELAY_LOW;                // RELAY_RESET pin low
  
  relay_mode = RELAY_CLOSED;              // Now the relay is closed
}                                         


/******************************************************************************
Name       : Relay_Mode
Author     : Carlos Cossio
Parameters : None
Returns    : RELAY_OPEN or RELAY_CLOSED
Description: Return the latching relay state: open or closed
******************************************************************************/
unsigned char Relay_Mode (void)
{	
  return relay_mode;                      // Return relay status
}
